﻿using System;
using System.Windows.Forms;
using NoteMan.Properties;

namespace NoteMan
{
    public partial class Form1 : Form
    {
        private readonly Data d = new Data();

        public Form1()
        {
            InitializeComponent();
            listProjects.DisplayMember = "Title";
            listProjects.DataSource = d.GetProjectList();
        }

        private void toolStripBtnExitApplication_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void toolStripBtnNewProject_Click(object sender, EventArgs e)
        {
            TextInput ti = new TextInput();
            string title = ti.Show("Project name:", "");
            if (title != null)
            {
                d.AddProject(title);
            }
        }

        private void listProjects_SelectedValueChanged(object sender, EventArgs e)
        {
            d.CurrentProject = listProjects.SelectedItem as Project;
            if (d.CurrentProject == null) return;
            dataAppointments.DataSource = d.CurrentProject.GetAppointments();
            dataTodos.DataSource = d.CurrentProject.GetTodos();
            dataNotes.DataSource = d.CurrentProject.GetNotes();
        }

        private void toolStripBtnNewElement_Click(object sender, EventArgs e)
        {
            // distinguish the different types
            if (tabConrtolElements.SelectedTab == tabTodos)
            {
                d.CurrentProject.Add(new Todo());
                dataTodos.DataSource = d.CurrentProject.GetTodos();
            }
            else if (tabConrtolElements.SelectedTab == tabAppointments)
            {
                d.CurrentProject.Add(new Appointment());
                dataAppointments.DataSource = d.CurrentProject.GetAppointments();
            }
            else if (tabConrtolElements.SelectedTab == tabNotes)
            {
                d.CurrentProject.Add(new Note());
                dataNotes.DataSource = d.CurrentProject.GetNotes();
            }
        }

        private void dataTodos_CurrentCellChanged(object sender, EventArgs e)
        {
            if (dataTodos.CurrentRow?.DataBoundItem == null) return;
            var elem = (Todo) dataTodos.CurrentRow.DataBoundItem;
            textTodoTitle.Text = elem.Title;
            textTodoDescription.Text = elem.Text;
            dateTimePickerTodoDeadline.Value = elem.Deadline;
        }

        private void toolStripBtnExportXml_Click(object sender, EventArgs e)
        {
            SaveFileDialog sfd = new SaveFileDialog
            {
                DefaultExt = "xml",
                AddExtension = true,
                Filter = Resources.ExportFileTypeXML,
                InitialDirectory = Environment.GetFolderPath(Environment.SpecialFolder.MyDocuments)
            };
            DialogResult r = sfd.ShowDialog();

            if (r == DialogResult.OK)
            {
                d.ExportXml(sfd.FileName);
            }

        }

        private void toolStripBtnSaveElement_Click(object sender, EventArgs e)
        {
            // distinguish the different types
            if (tabConrtolElements.SelectedTab == tabTodos)
            {
                if (dataTodos.CurrentRow?.DataBoundItem == null) return;
                Todo elem = (Todo) dataTodos.CurrentRow.DataBoundItem;
                elem.Title = textTodoTitle.Text;
                elem.Text = textTodoDescription.Text;
                elem.Deadline = dateTimePickerTodoDeadline.Value;
            }
            else if (tabConrtolElements.SelectedTab == tabAppointments)
            {
                if (dataAppointments.CurrentRow?.DataBoundItem == null) return;
                Appointment elem = (Appointment) dataAppointments.CurrentRow.DataBoundItem;
                elem.UpdateRecord(textAppointmentTitle.Text, textAppointmentDescription.Text, dateTimePickerAppointmentStart.Value, dateTimePickerAppointmentEnd.Value);
            }
            else if (tabConrtolElements.SelectedTab == tabNotes)
            {
                if (dataNotes.CurrentRow?.DataBoundItem == null) return;
                Note elem = (Note) dataNotes.CurrentRow.DataBoundItem;
                elem.UpdateRecord(textNotesTitle.Text, textNotesNote.Text);
            }
        }

        private void toolStripBtnDeleteElement_Click(object sender, EventArgs e)
        {
            // distinguish the different types
            if (tabConrtolElements.SelectedTab == tabTodos)
            {
                if (dataTodos.CurrentRow?.DataBoundItem == null) return;
                Todo elem = (Todo) dataTodos.CurrentRow.DataBoundItem;
                d.CurrentProject.Elements.Remove(elem);
            }
            else if (tabConrtolElements.SelectedTab == tabAppointments)
            {
                if (dataAppointments.CurrentRow?.DataBoundItem == null) return;
                Appointment elem = (Appointment) dataAppointments.CurrentRow.DataBoundItem;
                d.CurrentProject.Elements.Remove(elem);
            }
            else if (tabConrtolElements.SelectedTab == tabNotes)
            {
                if (dataNotes.CurrentRow?.DataBoundItem == null) return;
                Note elem = (Note) dataNotes.CurrentRow.DataBoundItem;
                d.CurrentProject.Elements.Remove(elem);
            }
        }

        private void dataAppointments_CurrentCellChanged(object sender, EventArgs e)
        {
            if (dataAppointments.CurrentRow?.DataBoundItem != null)
            {
                Appointment elem = (Appointment) dataAppointments.CurrentRow.DataBoundItem;
                textAppointmentTitle.Text = elem.Title;
                textAppointmentDescription.Text = elem.Text;
                dateTimePickerAppointmentStart.Value = elem.Start;
                dateTimePickerAppointmentEnd.Value = elem.End;
            }
        }

        private void dataNotes_CurrentCellChanged(object sender, EventArgs e)
        {

            if (dataNotes.CurrentRow?.DataBoundItem != null)
            {
                Note elem = (Note) dataNotes.CurrentRow.DataBoundItem;
                textNotesTitle.Text = elem.Title;
                textNotesNote.Text = elem.Text;
            }
        }

        private void toolStripBtnRenameProject_Click(object sender, EventArgs e)
        {
            
            TextInput ti = new TextInput();
            string title = ti.Show("New project name:", d.CurrentProject.Title);
            d.CurrentProject.Title = title;
        }
    }
}
